This is the mail archive of the binutils@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

C6X attribute renumbering


A new revision of the C6X ABI has changed the number of the architecture 
attribute (to avoid a notional conflict with Tag_Section - although as I 
noted in <http://sourceware.org/ml/binutils/2010-06/msg00229.html>, there 
is no actual ambiguity) and also changed the attribute name and the 
section in which attributes go.  I've applied this patch to update 
binutils to match the new ABI and new versions of the TI tools.  (Support 
for various new attributes added in this ABI will follow in due course.)

bfd:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* elf32-tic6x.c (elf32_tic6x_merge_arch_attributes): Update for
	attribute renaming.
	(elf_backend_obj_attrs_section): Change to ".c6xabi.attributes".

binutils:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* readelf.c (display_tic6x_attribute): Update for attribute
	renaming.

gas:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* config/tc-tic6x.c (tic6x_arch_attribute, tic6x_arches,
	md_assemble, tic6x_set_attributes): Update for attribute renaming.
	* doc/c-tic6x.texi: Update for attribute renaming.

gas/testsuite:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* gas/tic6x/attr-arch-directive-1.d,
	gas/tic6x/attr-arch-directive-2.d,
	gas/tic6x/attr-arch-directive-3.d,
	gas/tic6x/attr-arch-directive-4.d,
	gas/tic6x/attr-arch-directive-4.s,
	gas/tic6x/attr-arch-directive-5.d,
	gas/tic6x/attr-arch-directive-5.s,
	gas/tic6x/attr-arch-opts-c62x.d, gas/tic6x/attr-arch-opts-c64x+.d,
	gas/tic6x/attr-arch-opts-c64x.d, gas/tic6x/attr-arch-opts-c674x.d,
	gas/tic6x/attr-arch-opts-c67x+.d, gas/tic6x/attr-arch-opts-c67x.d,
	gas/tic6x/attr-arch-opts-none-1.d,
	gas/tic6x/attr-arch-opts-none-2.d,
	gas/tic6x/attr-arch-opts-override-1.d,
	gas/tic6x/attr-arch-opts-override-2.d: Update for attribute
	renaming and renumbering.

include/elf:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* tic6x-attrs.h (Tag_C6XABI_Tag_CPU_arch): Change to Tag_ISA,
	value 4.
	* tic6x.h (Values for Tag_C6XABI_Tag_CPU_arch): Rename for
	attribute renaming.

ld:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* emulparams/elf32_tic6x_le.sh (ATTRS_SECTIONS): Use
	.c6xabi.attributes, not __TI_build_attributes.

ld/testsuite:
2010-10-21  Joseph Myers  <joseph@codesourcery.com>

	* ld-tic6x/attr-arch-c62x-c62x.d, ld-tic6x/attr-arch-c62x-c64x+.d,
	ld-tic6x/attr-arch-c62x-c64x.d, ld-tic6x/attr-arch-c62x-c674x.d,
	ld-tic6x/attr-arch-c62x-c67x+.d, ld-tic6x/attr-arch-c62x-c67x.d,
	ld-tic6x/attr-arch-c64x+-c62x.d, ld-tic6x/attr-arch-c64x+-c64x+.d,
	ld-tic6x/attr-arch-c64x+-c64x.d, ld-tic6x/attr-arch-c64x+-c674x.d,
	ld-tic6x/attr-arch-c64x+-c67x+.d, ld-tic6x/attr-arch-c64x+-c67x.d,
	ld-tic6x/attr-arch-c64x-c62x.d, ld-tic6x/attr-arch-c64x-c64x+.d,
	ld-tic6x/attr-arch-c64x-c64x.d, ld-tic6x/attr-arch-c64x-c674x.d,
	ld-tic6x/attr-arch-c64x-c67x+.d, ld-tic6x/attr-arch-c64x-c67x.d,
	ld-tic6x/attr-arch-c674x-c62x.d, ld-tic6x/attr-arch-c674x-c64x+.d,
	ld-tic6x/attr-arch-c674x-c64x.d, ld-tic6x/attr-arch-c674x-c674x.d,
	ld-tic6x/attr-arch-c674x-c67x+.d, ld-tic6x/attr-arch-c674x-c67x.d,
	ld-tic6x/attr-arch-c67x+-c62x.d, ld-tic6x/attr-arch-c67x+-c64x+.d,
	ld-tic6x/attr-arch-c67x+-c64x.d, ld-tic6x/attr-arch-c67x+-c674x.d,
	ld-tic6x/attr-arch-c67x+-c67x+.d, ld-tic6x/attr-arch-c67x+-c67x.d,
	ld-tic6x/attr-arch-c67x-c62x.d, ld-tic6x/attr-arch-c67x-c64x+.d,
	ld-tic6x/attr-arch-c67x-c64x.d, ld-tic6x/attr-arch-c67x-c674x.d,
	ld-tic6x/attr-arch-c67x-c67x+.d, ld-tic6x/attr-arch-c67x-c67x.d:
	Update for attribute renaming.

Index: binutils/readelf.c
===================================================================
RCS file: /cvs/src/src/binutils/readelf.c,v
retrieving revision 1.516
diff -u -p -r1.516 readelf.c
--- binutils/readelf.c	9 Oct 2010 05:52:29 -0000	1.516
+++ binutils/readelf.c	21 Oct 2010 20:58:48 -0000
@@ -10770,32 +10770,32 @@ display_tic6x_attribute (unsigned char *
 
   switch (tag)
     {
-    case Tag_C6XABI_Tag_CPU_arch:
+    case Tag_ISA:
       val = read_uleb128 (p, &len);
       p += len;
-      printf ("  Tag_C6XABI_Tag_CPU_arch: ");
+      printf ("  Tag_ISA: ");
 
       switch (val)
 	{
-	case C6XABI_Tag_CPU_arch_none:
+	case C6XABI_Tag_ISA_none:
 	  printf (_("None\n"));
 	  break;
-	case C6XABI_Tag_CPU_arch_C62X:
+	case C6XABI_Tag_ISA_C62X:
 	  printf ("C62x\n");
 	  break;
-	case C6XABI_Tag_CPU_arch_C67X:
+	case C6XABI_Tag_ISA_C67X:
 	  printf ("C67x\n");
 	  break;
-	case C6XABI_Tag_CPU_arch_C67XP:
+	case C6XABI_Tag_ISA_C67XP:
 	  printf ("C67x+\n");
 	  break;
-	case C6XABI_Tag_CPU_arch_C64X:
+	case C6XABI_Tag_ISA_C64X:
 	  printf ("C64x\n");
 	  break;
-	case C6XABI_Tag_CPU_arch_C64XP:
+	case C6XABI_Tag_ISA_C64XP:
 	  printf ("C64x+\n");
 	  break;
-	case C6XABI_Tag_CPU_arch_C674X:
+	case C6XABI_Tag_ISA_C674X:
 	  printf ("C674x\n");
 	  break;
 	default:
Index: gas/doc/c-tic6x.texi
===================================================================
RCS file: /cvs/src/src/gas/doc/c-tic6x.texi,v
retrieving revision 1.2
diff -u -p -r1.2 c-tic6x.texi
--- gas/doc/c-tic6x.texi	9 Sep 2010 20:56:15 -0000	1.2
+++ gas/doc/c-tic6x.texi	21 Oct 2010 20:58:48 -0000
@@ -114,7 +114,7 @@ These have the same effects as @option{-
 Set the C6000 EABI build attribute @var{tag} to @var{value}.
 
 The @var{tag} is either an attribute number or
-@code{Tag_C6XABI_Tag_CPU_arch}.  The @var{value} is either a
+@code{Tag_ISA}.  The @var{value} is either a
 @code{number}, @code{"string"}, or @code{number, "string"} depending
 on the tag.
 
Index: gas/testsuite/gas/tic6x/attr-arch-directive-1.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-1.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-1.d
--- gas/testsuite/gas/tic6x/attr-arch-directive-1.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-1.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C62x
+  Tag_ISA: C62x
Index: gas/testsuite/gas/tic6x/attr-arch-directive-2.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-2.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-2.d
--- gas/testsuite/gas/tic6x/attr-arch-directive-2.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-2.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: gas/testsuite/gas/tic6x/attr-arch-directive-3.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-3.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-3.d
--- gas/testsuite/gas/tic6x/attr-arch-directive-3.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-3.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: gas/testsuite/gas/tic6x/attr-arch-directive-4.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-4.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-4.d
--- gas/testsuite/gas/tic6x/attr-arch-directive-4.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-4.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C62x
+  Tag_ISA: C62x
Index: gas/testsuite/gas/tic6x/attr-arch-directive-4.s
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-4.s,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-4.s
--- gas/testsuite/gas/tic6x/attr-arch-directive-4.s	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-4.s	21 Oct 2010 20:58:48 -0000
@@ -1,3 +1,3 @@
 # .c6xabi_attribute directives override other architecture information.
-.c6xabi_attribute 2, 1
+.c6xabi_attribute 4, 1
 .arch c674x
Index: gas/testsuite/gas/tic6x/attr-arch-directive-5.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-5.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-5.d
--- gas/testsuite/gas/tic6x/attr-arch-directive-5.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-5.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C62x
+  Tag_ISA: C62x
Index: gas/testsuite/gas/tic6x/attr-arch-directive-5.s
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-directive-5.s,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-directive-5.s
--- gas/testsuite/gas/tic6x/attr-arch-directive-5.s	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-directive-5.s	21 Oct 2010 20:58:48 -0000
@@ -1,3 +1,3 @@
 # .c6xabi_attribute directives override other architecture information.
 .arch c674x
-.c6xabi_attribute Tag_C6XABI_Tag_CPU_arch, 1
+.c6xabi_attribute Tag_ISA, 1
Index: gas/testsuite/gas/tic6x/attr-arch-opts-c62x.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-c62x.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-c62x.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-c62x.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C62x
+  Tag_ISA: C62x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-c64x+.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-c64x+.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-c64x+.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-c64x+.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: gas/testsuite/gas/tic6x/attr-arch-opts-c64x.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-c64x.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-c64x.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-c64x.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x
+  Tag_ISA: C64x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-c674x.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-c674x.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-c674x.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-c674x.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-c67x+.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-c67x+.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-c67x+.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-c67x+.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x\+
+  Tag_ISA: C67x\+
Index: gas/testsuite/gas/tic6x/attr-arch-opts-c67x.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-c67x.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-c67x.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-c67x.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x
+  Tag_ISA: C67x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-none-1.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-none-1.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-none-1.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-none-1.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-none-1.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-none-2.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-none-2.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-none-2.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-none-2.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-none-2.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-override-1.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-override-1.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-override-1.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-override-1.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-override-1.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C62x
+  Tag_ISA: C62x
Index: gas/testsuite/gas/tic6x/attr-arch-opts-override-2.d
===================================================================
RCS file: /cvs/src/src/gas/testsuite/gas/tic6x/attr-arch-opts-override-2.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-opts-override-2.d
--- gas/testsuite/gas/tic6x/attr-arch-opts-override-2.d	16 Jun 2010 00:36:03 -0000	1.1
+++ gas/testsuite/gas/tic6x/attr-arch-opts-override-2.d	21 Oct 2010 20:58:48 -0000
@@ -5,4 +5,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: include/elf/tic6x-attrs.h
===================================================================
RCS file: /cvs/src/src/include/elf/tic6x-attrs.h,v
retrieving revision 1.1
diff -u -p -r1.1 tic6x-attrs.h
--- include/elf/tic6x-attrs.h	16 Jun 2010 00:36:03 -0000	1.1
+++ include/elf/tic6x-attrs.h	21 Oct 2010 20:58:48 -0000
@@ -22,4 +22,4 @@
 /* Define the TAG macro before including this file; it takes a tag
    name and value.  */
 
-TAG(Tag_C6XABI_Tag_CPU_arch, 2)
+TAG(Tag_ISA, 4)
Index: ld/emulparams/elf32_tic6x_le.sh
===================================================================
RCS file: /cvs/src/src/ld/emulparams/elf32_tic6x_le.sh,v
retrieving revision 1.3
diff -u -p -r1.3 elf32_tic6x_le.sh
--- ld/emulparams/elf32_tic6x_le.sh	16 Jun 2010 00:36:03 -0000	1.3
+++ ld/emulparams/elf32_tic6x_le.sh	21 Oct 2010 20:58:48 -0000
@@ -37,4 +37,4 @@ OTHER_BSS_SECTIONS="
     . +=  0x100000;
     _STACK_START = .;
   }"
-ATTRS_SECTIONS='__TI_build_attributes 0 : { KEEP (*(__TI_build_attributes)) KEEP (*(.gnu.attributes)) }'
+ATTRS_SECTIONS='.c6xabi.attributes 0 : { KEEP (*(.c6xabi.attributes)) KEEP (*(.gnu.attributes)) }'
Index: ld/testsuite/ld-tic6x/attr-arch-c62x-c62x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c62x-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c62x-c62x.d
--- ld/testsuite/ld-tic6x/attr-arch-c62x-c62x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c62x-c62x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C62x
+  Tag_ISA: C62x
Index: ld/testsuite/ld-tic6x/attr-arch-c62x-c64x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c62x-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c62x-c64x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c62x-c64x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c62x-c64x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c62x-c64x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c62x-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c62x-c64x.d
--- ld/testsuite/ld-tic6x/attr-arch-c62x-c64x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c62x-c64x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x
+  Tag_ISA: C64x
Index: ld/testsuite/ld-tic6x/attr-arch-c62x-c674x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c62x-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c62x-c674x.d
--- ld/testsuite/ld-tic6x/attr-arch-c62x-c674x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c62x-c674x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c62x-c67x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c62x-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c62x-c67x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c62x-c67x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c62x-c67x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x\+
+  Tag_ISA: C67x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c62x-c67x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c62x-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c62x-c67x.d
--- ld/testsuite/ld-tic6x/attr-arch-c62x-c67x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c62x-c67x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x
+  Tag_ISA: C67x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x+-c62x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x+-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x+-c62x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x+-c62x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x+-c62x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x+-c64x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x+-c64x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x+-c64x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c64x+-c674x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x+-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x+-c674x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x+-c674x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x+-c674x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x+-c67x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x+-c67x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x+-c67x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x-c62x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x-c62x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x-c62x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x-c62x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x
+  Tag_ISA: C64x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x-c64x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x-c64x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x-c64x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x-c64x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x\+
+  Tag_ISA: C64x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c64x-c64x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x-c64x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x-c64x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x-c64x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C64x
+  Tag_ISA: C64x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x-c674x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x-c674x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x-c674x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x-c674x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x-c67x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x-c67x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x-c67x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x-c67x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c64x-c67x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c64x-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c64x-c67x.d
--- ld/testsuite/ld-tic6x/attr-arch-c64x-c67x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c64x-c67x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c674x-c62x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c674x-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c674x-c62x.d
--- ld/testsuite/ld-tic6x/attr-arch-c674x-c62x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c674x-c62x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c674x-c64x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c674x-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c674x-c64x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c674x-c64x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c674x-c64x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c674x-c64x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c674x-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c674x-c64x.d
--- ld/testsuite/ld-tic6x/attr-arch-c674x-c64x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c674x-c64x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c674x-c674x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c674x-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c674x-c674x.d
--- ld/testsuite/ld-tic6x/attr-arch-c674x-c674x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c674x-c674x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c674x-c67x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c674x-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c674x-c67x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c674x-c67x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c674x-c67x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c674x-c67x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c674x-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c674x-c67x.d
--- ld/testsuite/ld-tic6x/attr-arch-c674x-c67x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c674x-c67x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x+-c62x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x+-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x+-c62x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x+-c62x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x+-c62x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x\+
+  Tag_ISA: C67x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x+-c64x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x+-c64x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x+-c64x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x+-c674x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x+-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x+-c674x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x+-c674x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x+-c674x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x+-c67x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x\+
+  Tag_ISA: C67x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x+-c67x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x+-c67x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x\+
+  Tag_ISA: C67x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c67x-c62x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x-c62x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x-c62x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x-c62x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x-c62x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x
+  Tag_ISA: C67x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x-c64x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x-c64x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x-c64x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x-c64x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x-c64x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x-c64x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x-c64x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x-c64x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x-c64x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x-c64x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x-c674x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x-c674x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x-c674x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x-c674x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x-c674x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C674x
+  Tag_ISA: C674x
Index: ld/testsuite/ld-tic6x/attr-arch-c67x-c67x+.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x-c67x+.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x-c67x+.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x-c67x+.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x-c67x+.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x\+
+  Tag_ISA: C67x\+
Index: ld/testsuite/ld-tic6x/attr-arch-c67x-c67x.d
===================================================================
RCS file: /cvs/src/src/ld/testsuite/ld-tic6x/attr-arch-c67x-c67x.d,v
retrieving revision 1.1
diff -u -p -r1.1 attr-arch-c67x-c67x.d
--- ld/testsuite/ld-tic6x/attr-arch-c67x-c67x.d	16 Jun 2010 00:36:04 -0000	1.1
+++ ld/testsuite/ld-tic6x/attr-arch-c67x-c67x.d	21 Oct 2010 20:58:49 -0000
@@ -7,4 +7,4 @@
 
 Attribute Section: c6xabi
 File Attributes
-  Tag_C6XABI_Tag_CPU_arch: C67x
+  Tag_ISA: C67x

Index: bfd/elf32-tic6x.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-tic6x.c,v
retrieving revision 1.6
diff -u -p -r1.6 elf32-tic6x.c
--- bfd/elf32-tic6x.c	4 Oct 2010 14:13:09 -0000	1.6
+++ bfd/elf32-tic6x.c	21 Oct 2010 20:58:46 -0000
@@ -1673,7 +1673,7 @@ elf32_tic6x_obj_attrs_arg_type (int tag)
     return ATTR_TYPE_FLAG_INT_VAL;
 }
 
 /* Merge the Tag_C6XABI_Tag_CPU_arch attribute values ARCH1 and ARCH2
    and return the merged value.  At present, all merges succeed, so no
    return value for errors is defined.  */
 
@@ -1687,11 +1687,11 @@ elf32_tic6x_merge_arch_attributes (int a
 
   /* In most cases, the numerically greatest value is the correct
      merged value, but merging C64 and C67 results in C674X.  */
-  if ((min_arch == C6XABI_Tag_CPU_arch_C67X
-       || min_arch == C6XABI_Tag_CPU_arch_C67XP)
-      && (max_arch == C6XABI_Tag_CPU_arch_C64X
-	  || max_arch == C6XABI_Tag_CPU_arch_C64XP))
-    return C6XABI_Tag_CPU_arch_C674X;
+  if ((min_arch == C6XABI_Tag_ISA_C67X
+       || min_arch == C6XABI_Tag_ISA_C67XP)
+      && (max_arch == C6XABI_Tag_ISA_C64X
+	  || max_arch == C6XABI_Tag_ISA_C64XP))
+    return C6XABI_Tag_ISA_C674X;
 
   return max_arch;
 }
@@ -1724,9 +1724,9 @@ elf32_tic6x_merge_attributes (bfd *ibfd,
 
   /* No specification yet for handling of unknown attributes, so just
      ignore them and handle known ones.  */
-  out_attr[Tag_C6XABI_Tag_CPU_arch].i
-    = elf32_tic6x_merge_arch_attributes (in_attr[Tag_C6XABI_Tag_CPU_arch].i,
-					 out_attr[Tag_C6XABI_Tag_CPU_arch].i);
+  out_attr[Tag_ISA].i
+    = elf32_tic6x_merge_arch_attributes (in_attr[Tag_ISA].i,
+					 out_attr[Tag_ISA].i);
 
   /* Merge Tag_compatibility attributes and any common GNU ones.  */
   _bfd_elf_merge_object_attributes (ibfd, obfd);
@@ -1765,7 +1765,7 @@ elf32_tic6x_merge_private_bfd_data (bfd 
 #define elf_backend_may_use_rel_p	1
 #define elf_backend_may_use_rela_p	1
 #define elf_backend_obj_attrs_arg_type	elf32_tic6x_obj_attrs_arg_type
-#define elf_backend_obj_attrs_section	"__TI_build_attributes"
+#define elf_backend_obj_attrs_section	".c6xabi.attributes"
 #define elf_backend_obj_attrs_section_type	SHT_C6000_ATTRIBUTES
 #define elf_backend_obj_attrs_vendor	"c6xabi"
 #define elf_backend_rela_normal		1
@@ -1673,7 +1673,7 @@ elf32_tic6x_obj_attrs_arg_type (int tag)
 }
 
-/* Merge the Tag_C6XABI_Tag_CPU_arch attribute values ARCH1 and ARCH2
+/* Merge the Tag_ISA attribute values ARCH1 and ARCH2
    and return the merged value.  At present, all merges succeed, so no
    return value for errors is defined.  */
Index: gas/config/tc-tic6x.c
===================================================================
RCS file: /cvs/src/src/gas/config/tc-tic6x.c,v
retrieving revision 1.7
diff -u -p -r1.7 tc-tic6x.c
--- gas/config/tc-tic6x.c	7 Oct 2010 11:28:48 -0000	1.7
+++ gas/config/tc-tic6x.c	21 Oct 2010 20:58:48 -0000
@@ -82,9 +82,9 @@ static unsigned short tic6x_arch_enable 
    (architecture, as modified by other options).  */
 static unsigned short tic6x_features;
 
 /* The architecture attribute value, or C6XABI_Tag_CPU_arch_none if
    not yet set.  */
-static int tic6x_arch_attribute = C6XABI_Tag_CPU_arch_none;
+static int tic6x_arch_attribute = C6XABI_Tag_ISA_none;
 
 /* Whether any instructions at all have been seen.  Once any
    instructions have been seen, architecture attributes merge into the
@@ -120,21 +120,21 @@ typedef struct
 } tic6x_arch_table;
 static const tic6x_arch_table tic6x_arches[] =
   {
-    { "c62x", C6XABI_Tag_CPU_arch_C62X, TIC6X_INSN_C62X },
-    { "c64x", C6XABI_Tag_CPU_arch_C64X, TIC6X_INSN_C62X | TIC6X_INSN_C64X },
-    { "c64x+", C6XABI_Tag_CPU_arch_C64XP, (TIC6X_INSN_C62X
-					   | TIC6X_INSN_C64X
-					   | TIC6X_INSN_C64XP) },
-    { "c67x", C6XABI_Tag_CPU_arch_C67X, TIC6X_INSN_C62X | TIC6X_INSN_C67X },
-    { "c67x+", C6XABI_Tag_CPU_arch_C67XP, (TIC6X_INSN_C62X
-					   | TIC6X_INSN_C67X
-					   | TIC6X_INSN_C67XP) },
-    { "c674x", C6XABI_Tag_CPU_arch_C674X, (TIC6X_INSN_C62X
-					   | TIC6X_INSN_C64X
-					   | TIC6X_INSN_C64XP
-					   | TIC6X_INSN_C67X
-					   | TIC6X_INSN_C67XP
-					   | TIC6X_INSN_C674X) }
+    { "c62x", C6XABI_Tag_ISA_C62X, TIC6X_INSN_C62X },
+    { "c64x", C6XABI_Tag_ISA_C64X, TIC6X_INSN_C62X | TIC6X_INSN_C64X },
+    { "c64x+", C6XABI_Tag_ISA_C64XP, (TIC6X_INSN_C62X
+				      | TIC6X_INSN_C64X
+				      | TIC6X_INSN_C64XP) },
+    { "c67x", C6XABI_Tag_ISA_C67X, TIC6X_INSN_C62X | TIC6X_INSN_C67X },
+    { "c67x+", C6XABI_Tag_ISA_C67XP, (TIC6X_INSN_C62X
+				      | TIC6X_INSN_C67X
+				      | TIC6X_INSN_C67XP) },
+    { "c674x", C6XABI_Tag_ISA_C674X, (TIC6X_INSN_C62X
+				      | TIC6X_INSN_C64X
+				      | TIC6X_INSN_C64XP
+				      | TIC6X_INSN_C67X
+				      | TIC6X_INSN_C67XP
+				      | TIC6X_INSN_C674X) }
   };
 
 /* Update the selected architecture based on ARCH, giving an error if
@@ -2685,8 +2685,8 @@ md_assemble (char *str)
   /* If no .arch directives or -march options have been seen, we are
      assessing instruction validity based on the C674X default, so set
      the attribute accordingly.  */
-  if (tic6x_arch_attribute == C6XABI_Tag_CPU_arch_none)
-    tic6x_arch_attribute = C6XABI_Tag_CPU_arch_C674X;
+  if (tic6x_arch_attribute == C6XABI_Tag_ISA_none)
+    tic6x_arch_attribute = C6XABI_Tag_ISA_C674X;
 
   /* Reset global settings for parallel bars and predicates now to
      avoid extra errors if there are problems with this opcode.  */
@@ -3891,10 +3891,10 @@ tic6x_set_attribute_int (int tag, int va
 static void
 tic6x_set_attributes (void)
 {
-  if (tic6x_arch_attribute == C6XABI_Tag_CPU_arch_none)
-    tic6x_arch_attribute = C6XABI_Tag_CPU_arch_C674X;
+  if (tic6x_arch_attribute == C6XABI_Tag_ISA_none)
+    tic6x_arch_attribute = C6XABI_Tag_ISA_C674X;
 
-  tic6x_set_attribute_int (Tag_C6XABI_Tag_CPU_arch, tic6x_arch_attribute);
+  tic6x_set_attribute_int (Tag_ISA, tic6x_arch_attribute);
 }
 
 /* Do machine-dependent manipulations of the frag chains after all
@@ -82,9 +82,9 @@ static unsigned short tic6x_arch_enable 
 static unsigned short tic6x_features;
 
-/* The architecture attribute value, or C6XABI_Tag_CPU_arch_none if
+/* The architecture attribute value, or C6XABI_Tag_ISA_none if
    not yet set.  */
Index: include/elf/tic6x.h
===================================================================
RCS file: /cvs/src/src/include/elf/tic6x.h,v
retrieving revision 1.2
diff -u -p -r1.2 tic6x.h
--- include/elf/tic6x.h	16 Jun 2010 00:36:03 -0000	1.2
+++ include/elf/tic6x.h	21 Oct 2010 20:58:48 -0000
@@ -134,17 +134,17 @@ enum
     Tag_C6XABI_last
   };
 
-/* Values for Tag_C6XABI_Tag_CPU_arch.  GNU-specific names pending any
-   ABI defining official names associated with the values.  */
+/* Values for Tag_ISA.  GNU-specific names; the ABI does not specify
+   names for these values.  */
 enum
   {
-    C6XABI_Tag_CPU_arch_none = 0,
-    C6XABI_Tag_CPU_arch_C62X = 1,
-    C6XABI_Tag_CPU_arch_C67X = 3,
-    C6XABI_Tag_CPU_arch_C67XP = 4,
-    C6XABI_Tag_CPU_arch_C64X = 6,
-    C6XABI_Tag_CPU_arch_C64XP = 7,
-    C6XABI_Tag_CPU_arch_C674X = 8
+    C6XABI_Tag_ISA_none = 0,
+    C6XABI_Tag_ISA_C62X = 1,
+    C6XABI_Tag_ISA_C67X = 3,
+    C6XABI_Tag_ISA_C67XP = 4,
+    C6XABI_Tag_ISA_C64X = 6,
+    C6XABI_Tag_ISA_C64XP = 7,
+    C6XABI_Tag_ISA_C674X = 8
   };
 
 #endif /* _ELF_TIC6X_H */
-- 
Joseph S. Myers
joseph@codesourcery.com


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]